@@ -121,7 +121,7 @@ extern PGDLLEXPORT Datum ora_nlssort(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_set_nls_sort(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_lnnvl(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_decode(PG_FUNCTION_ARGS);
-extern PGDLLEXPORT Datum ora_dump(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_dump(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_get_major_version(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_get_major_version_num(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum ora_get_full_version_num(PG_FUNCTION_ARGS);
@@ -276,13 +276,12 @@ extern PGDLLEXPORT Datum orafce_bpcharlen(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum varchar2in(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum varchar2out(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum varchar2(PG_FUNCTION_ARGS);
-extern PGDLLEXPORT Datum varchar2typmodin(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum varchar2recv(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_concat2(PG_FUNCTION_ARGS);
 
 /* from nvarchar2.c */
 extern PGDLLEXPORT Datum nvarchar2in(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum nvarchar2out(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum nvarchar2(PG_FUNCTION_ARGS);
-extern PGDLLEXPORT Datum nvarchar2typmodin(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum nvarchar2recv(PG_FUNCTION_ARGS);
 #endif
