@@ -43,7 +43,7 @@ weekday_search(const WeekDays *weekdays, const char *str, int len)
 
 	for (i = 0; i < 7; i++)
 	{
-		int	n = strlen(weekdays->names[i]);
+		size_t	n = strlen(weekdays->names[i]);
 		if (n > len)
 			continue;	/* too short */
 		if (pg_strncasecmp(weekdays->names[i], str, n) == 0)
@@ -901,6 +901,7 @@ ora_timestamptz_round(PG_FUNCTION_ARGS)
 					 errmsg("timestamp out of range")));
 
 	tm_round(tm, fmt, &redotz);
+	fsec = 0;
 
 	if (redotz)
 		tz = DetermineTimeZoneOffset(tm, get_session_timezone(fcinfo));
