@@ -1,17 +1,29 @@
+/*
+ * This functionality doesn't work on Microsoft Windows. Probably, there are more
+ * than one issue:
+ *
+ *  functions fwrite, fclose, .. fails on segfault when file is locked. Probably 
+ *  PostgreSQL process and extension is not fully initialized and these "safe"
+ *  functions crashes. Possible solution is nolock thread unsafe functions like
+ *  _fwrite_nolock, It doesn't crash, but doesn't work. Returned file - file handler
+ *  is not valid (although fileptr is not NULL). 
+ *
+ *  From these reasons, this functionality is blocked on MS Windows.
+ */
+
 #ifdef _MSC_VER
 #define _CRT_SECURE_NO_DEPRECATE
 #endif
 
 #include "postgres.h"
 
+#include <errno.h>
 #include <unistd.h>
 #include <sys/stat.h>
 
 #include "executor/spi.h"
 
-#if PG_VERSION_NUM >= 90300
 #include "access/htup_details.h"
-#endif
 #include "catalog/pg_type.h"
 #include "fmgr.h"
 #include "funcapi.h"
@@ -60,6 +72,10 @@ PG_FUNCTION_INFO_V1(utl_file_tmpdir);
 		 errmsg("%s", msg), \
 		 errdetail("%s", detail)))
 
+#define STRERROR_EXCEPTION(msg) \
+	do { char *strerr = strerror(errno); CUSTOM_EXCEPTION(msg, strerr); } while(0);
+
+
 #define INVALID_FILEHANDLE_EXCEPTION()	CUSTOM_EXCEPTION(INVALID_FILEHANDLE, "Used file handle isn't valid.")
 
 #define CHECK_FILE_HANDLE() \
@@ -168,11 +184,11 @@ IO_EXCEPTION(void)
 		case ENAMETOOLONG:
 		case ENOENT:
 		case ENOTDIR:
-			CUSTOM_EXCEPTION(INVALID_PATH, strerror(errno));
+			STRERROR_EXCEPTION(INVALID_PATH);
 			break;
 
 		default:
-			CUSTOM_EXCEPTION(INVALID_OPERATION, strerror(errno));
+			STRERROR_EXCEPTION(INVALID_OPERATION);
 	}
 }
 
@@ -201,6 +217,13 @@ utl_file_fopen(PG_FUNCTION_ARGS)
 	char	   *fullname;
 	int			d;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
+
 	NOT_NULL_ARG(0);
 	NOT_NULL_ARG(1);
 	NOT_NULL_ARG(2);
@@ -281,6 +304,12 @@ utl_file_fopen(PG_FUNCTION_ARGS)
 Datum
 utl_file_is_open(PG_FUNCTION_ARGS)
 {
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	if (!PG_ARGISNULL(0))
 	{
 		int	i;
@@ -310,8 +339,14 @@ get_line(FILE *f, int max_linesize, int encoding, bool *iseof)
 	char *bpt;
 	int csize = 0;
 	text *result = NULL;
-
 	bool eof = true;
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
+	
 
 	buffer = palloc(max_linesize + 2);
 	bpt = buffer;
@@ -343,7 +378,7 @@ get_line(FILE *f, int max_linesize, int encoding, bool *iseof)
 	if (!eof)
 	{
 		char   *decoded;
-		int		len;
+		size_t		len;
 
 		pg_verify_mbstr(encoding, buffer, csize, false);
 		decoded = (char *) pg_do_encoding_conversion((unsigned char *) buffer,
@@ -368,7 +403,7 @@ get_line(FILE *f, int max_linesize, int encoding, bool *iseof)
 				break;
 
 			default:
-				CUSTOM_EXCEPTION(READ_ERROR, strerror(errno));
+				STRERROR_EXCEPTION(READ_ERROR);
 				break;
 		}
 
@@ -398,6 +433,12 @@ utl_file_get_line(PG_FUNCTION_ARGS)
 	text   *result;
 	bool	iseof;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), &max_linesize, &encoding);
 
@@ -440,6 +481,12 @@ utl_file_get_nextline(PG_FUNCTION_ARGS)
 	text   *result;
 	bool	iseof;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), &max_linesize, &encoding);
 
@@ -459,7 +506,7 @@ do_flush(FILE *f)
 		if (errno == EBADF)
 			CUSTOM_EXCEPTION(INVALID_OPERATION, "File is not an opened, or is not open for writing");
 		else
-			CUSTOM_EXCEPTION(WRITE_ERROR, strerror(errno));
+			STRERROR_EXCEPTION(WRITE_ERROR);
 	}
 }
 
@@ -483,12 +530,12 @@ do_flush(FILE *f)
 			CUSTOM_EXCEPTION(INVALID_OPERATION, "file descriptor isn't valid for writing"); \
 			break; \
 		default: \
-			CUSTOM_EXCEPTION(WRITE_ERROR, strerror(errno)); \
+			STRERROR_EXCEPTION(WRITE_ERROR); \
 	}
 
 /* encode(t, encoding) */
 static char *
-encode_text(int encoding, text *t, int *length)
+encode_text(int encoding, text *t, size_t *length)
 {
 	char	   *src = VARDATA_ANY(t);
 	char	   *encoded;
@@ -501,12 +548,12 @@ encode_text(int encoding, text *t, int *length)
 }
 
 /* fwrite(encode(args[n], encoding), f) */
-static int
-do_write(PG_FUNCTION_ARGS, int n, FILE *f, int max_linesize, int encoding)
+static size_t
+do_write(PG_FUNCTION_ARGS, int n, FILE *f, size_t max_linesize, int encoding)
 {
 	text	   *arg = PG_GETARG_TEXT_P(n);
 	char	   *str;
-	int			len;
+	size_t			len;
 
 	str = encode_text(encoding, arg, &len);
 	CHECK_LENGTH(len);
@@ -539,6 +586,12 @@ do_put(PG_FUNCTION_ARGS)
 Datum
 utl_file_put(PG_FUNCTION_ARGS)
 {
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	do_put(fcinfo);
 	PG_RETURN_BOOL(true);
 }
@@ -565,6 +618,12 @@ utl_file_put_line(PG_FUNCTION_ARGS)
 	FILE   *f;
 	bool	autoflush;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	f = do_put(fcinfo);
 
 	autoflush = PG_GETARG_IF_EXISTS(2, BOOL, false);
@@ -583,6 +642,12 @@ utl_file_new_line(PG_FUNCTION_ARGS)
 	FILE   *f;
 	int		lines;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), NULL, NULL);
 	lines = PG_GETARG_IF_EXISTS(1, INT32, 1);
@@ -614,10 +679,16 @@ utl_file_putf(PG_FUNCTION_ARGS)
 	char   *format;
 	int		max_linesize;
 	int		encoding;
-	int		format_length;
+	size_t		format_length;
 	char   *fpt;
 	int		cur_par = 0;
-	int		cur_len = 0;
+	size_t		cur_len = 0;
+
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
 
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), &max_linesize, &encoding);
@@ -683,6 +754,12 @@ utl_file_fflush(PG_FUNCTION_ARGS)
 {
 	FILE *f;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), NULL, NULL);
 	do_flush(f);
@@ -709,6 +786,12 @@ utl_file_fclose(PG_FUNCTION_ARGS)
 	int i;
 	int	d = PG_GETARG_INT32(0);
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	for (i = 0; i < MAX_SLOTS; i++)
 	{
 		if (slots[i].id == d)
@@ -718,7 +801,7 @@ utl_file_fclose(PG_FUNCTION_ARGS)
 				if (errno == EBADF)
 					CUSTOM_EXCEPTION(INVALID_FILEHANDLE, "File is not an opened");
 				else
-					CUSTOM_EXCEPTION(WRITE_ERROR, strerror(errno));
+					STRERROR_EXCEPTION(WRITE_ERROR);
 			}
 			slots[i].file = NULL;
 			slots[i].id = INVALID_SLOTID;
@@ -744,6 +827,12 @@ utl_file_fclose_all(PG_FUNCTION_ARGS)
 {
 	int i;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	for (i = 0; i < MAX_SLOTS; i++)
 	{
 		if (slots[i].id != INVALID_SLOTID)
@@ -753,7 +842,7 @@ utl_file_fclose_all(PG_FUNCTION_ARGS)
 				if (errno == EBADF)
 					CUSTOM_EXCEPTION(INVALID_FILEHANDLE, "File is not an opened");
 				else
-					CUSTOM_EXCEPTION(WRITE_ERROR, strerror(errno));
+					STRERROR_EXCEPTION(WRITE_ERROR);
 			}
 			slots[i].file = NULL;
 			slots[i].id = INVALID_SLOTID;
@@ -865,6 +954,12 @@ utl_file_fremove(PG_FUNCTION_ARGS)
 {
 	char	   *fullname;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	NOT_NULL_ARG(0);
 	NOT_NULL_ARG(1);
 
@@ -891,6 +986,12 @@ utl_file_frename(PG_FUNCTION_ARGS)
 	char	   *dstpath;
 	bool		overwrite;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	NOT_NULL_ARG(0);
 	NOT_NULL_ARG(1);
 	NOT_NULL_ARG(2);
@@ -935,6 +1036,12 @@ utl_file_fcopy(PG_FUNCTION_ARGS)
 	FILE	   *srcfile;
 	FILE	   *dstfile;
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	NOT_NULL_ARG(0);
 	NOT_NULL_ARG(1);
 	NOT_NULL_ARG(2);
@@ -1039,6 +1146,12 @@ utl_file_fgetattr(PG_FUNCTION_ARGS)
 	Datum		values[3];
 	bool		nulls[3] = { 0 };
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	NOT_NULL_ARG(0);
 	NOT_NULL_ARG(1);
 
@@ -1090,5 +1203,11 @@ utl_file_tmpdir(PG_FUNCTION_ARGS)
 	canonicalize_path(tmpdir);
 #endif
 
+#ifdef _MSC_VER
+
+	elog(ERROR, "utl_file package is not supported on Microsoft Windows");
+
+#endif
+
 	PG_RETURN_TEXT_P(cstring_to_text(tmpdir));
 }
