@@ -1,9 +1,7 @@
 #include "postgres.h"
 #include "funcapi.h"
 #include "fmgr.h"
-#if PG_VERSION_NUM >= 90300
 #include "access/htup_details.h"
-#endif
 #include "storage/shmem.h"
 #include "utils/memutils.h"
 #include "utils/timestamp.h"
@@ -22,7 +20,7 @@
 #include "builtins.h"
 
 /*
- * @ Pavel Stehule 2006
+ * @ Pavel Stehule 2006-2018
  */
 
 #ifndef _GetCurrentTimestamp
@@ -147,16 +145,8 @@ message_buffer *input_buffer = NULL;
 
 pipe* pipes = NULL;
 
-#if PG_VERSION_NUM >= 90400
-
 #define NOT_INITIALIZED		NULL
 
-#else
-
-#define NOT_INITIALIZED		-1
-
-#endif
-
 LWLockId shmem_lockid = NOT_INITIALIZED;;
 
 unsigned int sid;                                 /* session id */
@@ -996,7 +986,6 @@ dbms_pipe_list_pipes(PG_FUNCTION_ARGS)
 {
 	FuncCallContext *funcctx;
 	TupleDesc        tupdesc;
-	TupleTableSlot  *slot;
 	AttInMetadata   *attinmeta;
 	PipesFctx       *fctx;
 
@@ -1027,7 +1016,16 @@ dbms_pipe_list_pipes(PG_FUNCTION_ARGS)
 		funcctx->user_fctx = fctx;
 		fctx->pipe_nth = 0;
 
-		tupdesc = CreateTemplateTupleDesc(DB_PIPES_COLS , false);
+#if PG_VERSION_NUM >= 120000
+
+		tupdesc = CreateTemplateTupleDesc(DB_PIPES_COLS);
+
+#else
+
+		tupdesc = CreateTemplateTupleDesc(DB_PIPES_COLS, false);
+
+#endif
+
 		i = 0;
 		TupleDescInitEntry(tupdesc, ++i, "name",    VARCHAROID, -1, 0);
 		TupleDescInitEntry(tupdesc, ++i, "items",   INT4OID,    -1, 0);
@@ -1037,9 +1035,6 @@ dbms_pipe_list_pipes(PG_FUNCTION_ARGS)
 		TupleDescInitEntry(tupdesc, ++i, "owner",   VARCHAROID, -1, 0);
 		Assert(i == DB_PIPES_COLS);
 
-		slot = TupleDescGetSlot(tupdesc);
-		funcctx->slot = slot;
-
 		attinmeta = TupleDescGetAttInMetadata(tupdesc);
 		funcctx->attinmeta = attinmeta;
 
@@ -1082,7 +1077,7 @@ dbms_pipe_list_pipes(PG_FUNCTION_ARGS)
 			values[5] = pipes[fctx->pipe_nth].creator;
 
 			tuple = BuildTupleFromCStrings(funcctx->attinmeta, values);
-			result = TupleGetDatum(funcctx->slot, tuple);
+			result = HeapTupleGetDatum(tuple);
 
 			fctx->pipe_nth += 1;
 			SRF_RETURN_NEXT(funcctx, result);
