@@ -22,8 +22,11 @@
 PG_FUNCTION_INFO_V1(varchar2in);
 PG_FUNCTION_INFO_V1(varchar2out);
 PG_FUNCTION_INFO_V1(varchar2);
-PG_FUNCTION_INFO_V1(varchar2typmodin);
 PG_FUNCTION_INFO_V1(varchar2recv);
+PG_FUNCTION_INFO_V1(orafce_concat2);
+
+bool orafce_varchar2_null_safe_concat = false;
+
 
 /*
  * varchar2_input -- common guts of varchar2in and varchar2recv
@@ -180,3 +183,59 @@ varchar2(PG_FUNCTION_ARGS)
  *
  * just use varchartypmodout()
  */
+
+
+/*
+ * orafce_concat2 - null safe concat
+ *
+ * returns NULL instead empty string
+ */
+Datum
+orafce_concat2(PG_FUNCTION_ARGS)
+{
+	text	   *arg1 = NULL,
+			   *arg2 = NULL,
+			   *result;
+	int32		len1 = 0,
+				len2 = 0,
+				len;
+	char	   *ptr;
+
+	if (!PG_ARGISNULL(0))
+	{
+		arg1 = PG_GETARG_TEXT_PP(0);
+		len1 = VARSIZE_ANY_EXHDR(arg1);
+	}
+	if (!PG_ARGISNULL(1))
+	{
+		arg2 = PG_GETARG_TEXT_PP(1);
+		len2 = VARSIZE_ANY_EXHDR(arg2);
+	}
+
+	/* default behave should be compatible with Postgres */
+	if (!orafce_varchar2_null_safe_concat)
+	{
+		if (PG_ARGISNULL(0) || PG_ARGISNULL(1))
+			PG_RETURN_NULL();
+	}
+	else
+	{
+		if (len1 == 0 && len2 == 0)
+			PG_RETURN_NULL();
+	}
+
+	/* hard work, we should to concat strings */
+	len = len1 + len2 + VARHDRSZ;
+
+	result = (text *) palloc(len);
+	SET_VARSIZE(result, len);
+
+	ptr = VARDATA(result);
+
+	if (len1 > 0)
+		memcpy(ptr, VARDATA_ANY(arg1), len1);
+	if (len2 > 0)
+		memcpy(ptr + len1, VARDATA_ANY(arg2), len2);
+
+	PG_RETURN_TEXT_P(result);
+}
